pub struct CreateEncoderParams {
pub input_details: Option<FormatDetails>,
pub require_hw: Option<bool>,
pub codec_specifier: Option<String>,
/* private fields */
}Expand description
Parameters used to request an encoder.
Fields
input_details: Option<FormatDetails>The format of the uncompressed input data.
This field should be a raw mime_type (e.g. ‘video/raw’) and uncompressed format details for the encoder to use when reading buffers.
To be elibigible an encoder must support the input format.
require_hw: Option<bool>If true, require that the returned codec is HW-accelerated.
If not set, interpreted as false.
codec_specifier: Option<String>If set to a value obtained from
[fuchsia.mediacodec/DetailedCodecDescription.codec_specifier], the
create request will create the specified codec or fail. The client
should still set other fields in this table as appropriate, so that the
codec factory can ensure that the codec will meet the client’s
requirements (and to convey oob_bytes as needed). More than one codec
reported by from [fuchsia.mediacodec/DetailedCodecDescription] can
have the same codec_specifier iff the underlying implementation is the
same. A codec implementation may change its codec_specifier(s) each
boot, whether updated to a new implementation version or not.