pub struct DetailedCodecDescription {
pub codec_type: Option<CodecType>,
pub mime_type: Option<String>,
pub is_hw: Option<bool>,
pub profile_descriptions: Option<ProfileDescriptions>,
pub supports_dynamic_buffers: Option<bool>,
pub dynamic_buffers_input_max: Option<u32>,
pub dynamic_buffers_output_max: Option<u32>,
pub dynamic_buffers_video_decoder_output_safe: Option<u32>,
pub codec_specifier: Option<String>,
/* private fields */
}Expand description
Clients needing codec information prior to just requesting a codec with CodecFactory.CreateDecoder or CodecFactory.CreateEncoder should use GetDetailedCodecDescriptions to get this table, which has details re. the codec and the profile entries supported by the codec.
Clients with no real need for codec information prior to requesting a codec can simply use CodecFactory.CreateDecoder or CodecFactory.CreateEncoder with relevant requirements set in that request, and then call StreamProcessor.Sync (round trip) to see if a codec was created successfully.
Fields
codec_type: Option<CodecType>Decoder or encoder.
mime_type: Option<String>The mime type of the compressed format. For decoders this is the mime type of the input. For encoders, this is the mime type of the output.
is_hw: Option<bool>If this decoder/encoder uses underlying hardware to perform its operations.
profile_descriptions: Option<ProfileDescriptions>A list of profile descriptions that describe what codec profiles this encoder/decoder supports along with requirements for using each profile.
supports_dynamic_buffers: Option<bool>If set to true, dynamic buffers are supported by the codec. See also
[fuchsia.mediacodec/StreamProcessor.AddBuffer] and
[fuchsia.mediacodec/StreamProcessor.RemoveBuffer] which are required
to use dynamic buffers.
Regardless of whether AddBuffer and RemoveBuffer are used (vs.
SetInputBufferPartialSettings / SetOutputBufferPartialSettings), see
[fuchsia.mediacodec/StreamProcessor.EnableOldOutputBuffers] and
[fuchsia.mediacodec/StreamProcessor.EnableSameOutputBufferConcurrentlyInFlight]
which are only permitted when supports_dynamic_buffers is true. Both
of those are required to achieve full bitstream spec compliance with
some video bitstream formats such as VP9 (when show_existing_frame is
used in unusual ways).
This does not imply support for non-sysmem-provided VMOs.
dynamic_buffers_input_max: Option<u32>Having more than this many input buffers added and not yet completely removed under the latest buffer_lifetime_ordinal will result in async StreamProcessor channel closure.
dynamic_buffers_output_max: Option<u32>Having more than this many output buffers added and not yet completely removed under the latest buffer_lifetime_ordinal will result in async StreamProcessor channel closure.
dynamic_buffers_video_decoder_output_safe: Option<u32>This field is set when a codec both supports dynamic buffers and is a
video decoder. Adding this many buffers to a video decoder’s output, and
ensuring that the buffers will be usable by the decoder prior to the
whole pipeline blocking on lack of availability of usable output buffers
in the decoder, will ensure that the decoder doesn’t get stuck waiting
for an available output buffer. See also
[fuchsia.mediacodec/StreamBufferConstraints.buffer_count_for_server_current]
which may occasionally indicate a lower number of output buffers needed,
based on headers of the bitstream. However, implementers of clients may
wish to first check if the relevant headers in relevant streams are
actually set, since this can be rare in practice unfortunately, making
paying attention to buffer_count_for_server_current potentially not
actually worthwhile, depending on the expected streams’ headers.
codec_specifier: Option<String>Optionally set
[fuchsia.mediacodec/CreateDecoder_Params.codec_specifier] to this
string to require an instance of this specific codec. The created codec
will still be checked against other requirements specified there for the
codec to be created successfully.
This is only valid and specific per boot, not across boots. This allows a discovered codec to be requested without any ambiguity, but is intentionally not a way for clients to hard code which specific codec implementation they want to connect to, as codec selection is by properties / capabilities, not by specific codec implementation.